@@ -36,14 +36,6 @@ fi
 # configure build using meson
 meson setup builddir ${MESON_ARGS} "${meson_config_args[@]}"
 
-ninja -v -C builddir -j ${CPU_COUNT}
-ninja -C builddir test
-ninja -C builddir install
-
-# meson installs to the wrong location for PyPy, so move the files manually
-if [[ $python_impl == "pypy" ]] ; then
-    INSTALL_PLATLIB=$($PYTHON -c "import sysconfig; print(sysconfig.get_path('platlib'))")
-    cd $PREFIX/lib/pypy*/site-packages
-    mv *.egg-info $INSTALL_PLATLIB
-    mv cairo $INSTALL_PLATLIB
-fi
+meson compile -v -C builddir -j ${CPU_COUNT}
+meson test -C builddir --print-errorlogs --timeout-multiplier 10 --num-processes ${CPU_COUNT}
+meson install -C builddir
